import requests
import json

class Staff:
    def __init__(self, sQ):
        self.id = sQ
        query='''
query ($id: Int) {
  Staff(id: $id, sort: FAVOURITES_DESC) {
    id
    name {
      first
      last
      full
      native
    }
    language
    image {
      large
      medium
    }
    description
    isFavourite
    siteUrl
    staffMedia {
      edges {
        node {
          id
          title {
            romaji
            english
            native
          }
        }
      }
    }
  }
}

        '''
        variables = {
            'id': sQ
        }  

        url = 'https://graphql.anilist.co'
        self.sQ = sQ
        response = requests.post(url, json={'query': query, 'variables': variables})
        self.raw = json.loads(response.text)
        self.media = self.raw["data"]["Staff"]

    def _test(self):
        return self.media
    
    def reload(self):
      return self.__init__(self.sQ)
    def json(self):
      return self.raw
    
    # return the name of the staff
    def name(self, OPT: str):
      # OPT {full}{first}{last}{native}
      return self.media["name"][OPT]
    
    # returns the language of the staff
    def language(self):
      return self.media["language"]

    # returns the image of the staff
    def image(self, SIZE: str):
      # SIZE {large}{medium}
      return self.media["image"][SIZE]

    # return the description of the staff
    def description(self):
      return self.media["description"]
    
    def staffMedia(self):
      return self.media["staffMedia"]["edges"]
    
    



import requests
import json

from anilistpy.utils import videoLink

class Manga:
    def __init__(self, sQ):
    # init function
    # takes 1 arg -> sQ: id of the anime 
        self.id = sQ
        query = '''
query ($id: Int, $page: Int, $perPage: Int, $search: String) {
  Page(page: $page, perPage: $perPage) {
    media(id: $id, search: $search, type: MANGA) {
      id
      title {
        romaji
        english
        native
      }
      chapters
      description
      status
      genres
      averageScore
      meanScore
      countryOfOrigin
      source
      hashtag
      synonyms
      characters(role: MAIN){
        edges{
          node{
            name{
              full
            }
            id
          }
        }
      }
      volumes
      tags {
        name
      }
      staff(sort: FAVOURITES_DESC) {
        edges {
          node {
            name {
              full
            }
            id
          }
        }
      }
      startDate {
        year
        month
        day
      }
      endDate {
        year
        month
        day
      }
      coverImage {
        medium
        large
        extraLarge
      }
      bannerImage
      
    }
  }
}

        '''

        variables = {
            'id': sQ,
            'page': 1,
            'perPage': 1,
            'MediaType': "MANGA"
        }

        url = 'https://graphql.anilist.co'

        response = requests.post(url, json={'query': query, 'variables': variables})
        self.raw = json.loads(response.text)
        self.media = self.raw["data"]["Page"]["media"]

    # reloads the object. calls the init function
    def reload(self):
        self.__init__(self.id)
    # returns the raw json from the api request
    def json(self):
        return self.raw

    # returns the title, 1 arg: LA 
    def title(self, LA): # LA options: {romaji}{english}
        return self.media[0]["title"][LA]

    # returns the numbers of chapters, if the manga has not finished returns 0
    def chapters(self):
        return self.media[0]["chapters"]

    # same as above but with volumes
    def volumes(self):
        return self.media[0]["volumes"]

    # returns the manga description in md format
    def description(self):
        return self.media[0]["description"]

    # returns a list of genres 
    def genres(self):
        return self.media[0]["genres"]

    # returns the average score, out of 100
    def averageScore(self):
        return self.media[0]["averageScore"] 

    # returns the mean score
    def meanScore(self):
      return self.media[0]["meanScore"]

    # returns a list of tags     
    def tags(self):
      node = self.media[0]["tags"]
      return_list = []
      for i in range(0, len(node)):
        return_list.append(node[i]["name"])
        
      return return_list

    # returns the names/id of staffs involved
    # getID : True returns the list of id  
    # getID : False returns the list of name 
    def staff(self, getID: bool):
      _edges_staff = self.media[0]["staff"]["edges"]
      return_list = []
      
      if getID:
        for i in range(0, len(_edges_staff)):
          return_list.append(_edges_staff[i]["node"]["id"])
        
      elif getID is False:
        for i in range(0,len(_edges_staff)):
          return_list.append(_edges_staff[i]["node"]["name"]["full"])
      else: 
        return "error"
      
      return return_list

    # returns a dict of the starting date
    def startDate(self):
        return self.media[0]["startDate"]

    # returns a dict of the ending date
    def endDate(self):
        return self.media[0]["endDate"]

    # returns the url of the cover image, large ,medium and extraLarge
    def coverImage(self, SIZE):
        try:
          return self.media[0]["coverImage"][SIZE]
        except KeyError:
          return "key error: arg SIZE is incorrect"

    # returns the url of the banner image  
    def bannerImage(self):
        return self.media[0]["bannerImage"]
    
    # returns the status of the media
    def status(self):
        return self.media[0]["status"]
    
    # returns offical hashtags
    def hashtag(self):
      return self.media[0]["hashtag"]
    
    # returns synonyms 
    def synonyms(self):
      return self.media[0]["synonyms"]
    
    # returns country of origin
    def countryOfOrigin(self):
      return self.media[0]["countryOfOrigin"]



import requests
import json

class searchStaff:
    def __init__(self, sQ):
        query = '''
query ($sQ: String) {
  Page(page: 1, perPage: 6) {
    staff(search: $sQ) {
      id
      name {
        first
        last
        full
        native
      }
    }
  }
} 
       '''
        variables = {
            'sQ': sQ
        }

        url = 'https://graphql.anilist.co'

        response = requests.post(url, json={'query': query, 'variables': variables})
        raw = json.loads(response.text)
        self.media = raw["data"]["Page"]["staff"]

    def _test(self):
        return True

    def name(self, resultnumber: int):
        return self.media[resultnumber]["name"]["full"]
    def id(self, resultnumber: int):
        return self.media[resultnumber]["id"]


import requests
import json

class Studio:
    def __init__(self, sQ):
        self.id = sQ
        query='''
query ($id: Int) {
  Studio(id: $id) {
    id
    name
    media{
      nodes{
        title{
          romaji
        }
        id
        
      }
    }
  }
}

        '''
        variables = {
            'id': sQ
        }  

        url = 'https://graphql.anilist.co'

        response = requests.post(url, json={'query': query, 'variables': variables})
        self.raw = json.loads(response.text)
        self.media = self.raw["data"]["Studio"]

    def _test(self):
        return self.media

    def name(self):
        return self.media["name"]     
    def media(self):
        return self.media["media"]["nodes"]  



import requests
import json

from anilistpy.utils import videoLink

class Anime:
    # init function
    # takes 1 arg -> sQ: id of the anime  
    def __init__(self, sQ):
        self.id = sQ
        #graphql api query
        query = '''
query ($id: Int, $page: Int, $perPage: Int, $search: String) {
  Page(page: $page, perPage: $perPage) {
    media(id: $id, search: $search, type: ANIME) {
      id
      title {
        romaji
        english
        native
      }
      episodes
      description
      format
      status
      duration
      genres
      tags {
        name
      }
      studios {
        nodes {
          name
        }
      }
      startDate {
        year
        month
        day
      }
      endDate {
        year
        month
        day
      }
      season
      seasonYear
      seasonInt
      countryOfOrigin
      coverImage {
        medium
        large
        extraLarge
      }
      bannerImage
      source
      hashtag
      synonyms
      meanScore
      averageScore
      trailer {
        id
        thumbnail
        site
      }
      staff(sort: FAVOURITES_DESC) {
        edges {
          node {
            name {
              full
            }
            id
          }
        }
      }
      characters(role: MAIN) {
        edges {
          node {
            name {
              full
            }
          }
        }
      }
    }
  }
}
        '''

        variables = {
            'id': sQ,
            'page': 1,
            'perPage': 1,
            'MediaType': "ANIME"
        }

        url = 'https://graphql.anilist.co'

        response = requests.post(url, json={'query': query, 'variables': variables})
        self.raw = json.loads(response.text)
        self.media = self.raw["data"]["Page"]["media"]

    # reloads the object. calls the init function again      
    def reload(self):
        self.__init__(self.id)
    # returns the raw json returned from the api request
    def json(self):
        return self.raw
    
    # returns the title
    def title(self, LA: str): # LA options: {romaji}{english}{native}
        return self.media[0]["title"][LA]
    
    # returns the episodes
    def episodes(self):
        return self.media[0]["episodes"]
    
    # returns the anime description in md format
    def description(self):
        return self.media[0]["description"]
    
    # returns the duration of a single episode in minutes
    def duration(self):
        return self.media[0]["duration"]
    
    # returns a list of genres 
    def genres(self):
        return self.media[0]["genres"]
    
    # returns the average score, out of 100
    def averageScore(self):
        return self.media[0]["averageScore"]   
    
    # returns the mean score
    def meanScore(self):
      return self.media[0]["meanScore"]

    # returns a list of tags     
    def tags(self):
      node = self.media[0]["tags"]
      return_list = []
      for i in range(0, len(node)):
        return_list.append(node[i]["name"])
        
      return return_list
    
    # returns the names of studios involved
    def studios(self):
      node = self.media[0]["studios"]["nodes"]
      return_list = []
      for i in range(0, len(node)):
        return_list.append(node[i]["name"])
      
      return return_list
    
    # returns the names/id of staffs involved
    # getID : True returns the list of id  
    # getID : False returns the list of name 
    def staff(self, getID: bool):
      _edges_staff = self.media[0]["staff"]["edges"]
      return_list = []
      
      if getID:
        for i in range(0, len(_edges_staff)):
          return_list.append(_edges_staff[i]["node"]["id"])
        
      elif getID is False:
        for i in range(0,len(_edges_staff)):
          return_list.append(_edges_staff[i]["node"]["name"]["full"])
      else: 
        return "error"
      
      return return_list

    # returns the season it aired on
    def season(self):
        return self.media[0]["season"]
    
    # returns a dict of the starting date
    def startDate(self):
        return self.media[0]["startDate"]
    
    # returns a dict of the ending date
    def endDate(self):
        return self.media[0]["endDate"]
    
    # returns the url of the cover image, large ,medium and extraLarge
    def coverImage(self, SIZE):
        try:
          return self.media[0]["coverImage"][SIZE]
        except KeyError:
          return "key error: arg SIZE is incorrect"
    
    # returns the url of the banner image
    def bannerImage(self):
        return self.media[0]["bannerImage"]
    
    # returns the status of the media
    def status(self):
        return self.media[0]["status"]
    
    # returns offical hashtags
    def hashtag(self):
      return self.media[0]["hashtag"]
    
    # returns synonyms 
    def synonyms(self):
      return self.media[0]["synonyms"]
    
    # returns country of origin
    def countryOfOrigin(self):
      return self.media[0]["countryOfOrigin"]
    
    # returns trailer link
    def trailerlink(self):
      site = self.media[0]["trailer"]["site"]
      id = self.media[0]["trailer"]["id"]
      return videoLink(site, id)
    
    #returns trailer thubmnail
    def trailer_thumbnail(self):
      return self.media[0]["trailer"]["thumbnail"]


import requests
import json

class searchStudio:
    def __init__(self, sQ):
        query = '''
query ($sQ: String) {
  Page(page: 1, perPage: 6) {
    studios(search: $sQ) {
      id
      name
    }
  }
}
'''
        variables = {
            'sQ': sQ
        }

        url = 'https://graphql.anilist.co'

        response = requests.post(url, json={'query': query, 'variables': variables})
        raw = json.loads(response.text)
        self.media = raw["data"]["Page"]["studios"]
    
    def _test(self):
        return True

    def name(self, resultnumber: int):
        return self.media[resultnumber]["name"]
    def id(self, resultnumber: int):
        return self.media[resultnumber]["id"]


import requests
import json

class Character:
    def __init__(self, sQ):
        self.id = sQ
        query='''
query ($id: Int) {
  Character(id: $id, sort: FAVOURITES_DESC) {
    id
    name {
      first
      last
      full
      native
    }
    image {
      large
      medium
    }
    description
    isFavourite
    siteUrl
    media {
      edges {
        node{
          title {
            romaji
            english
            native
            userPreferred
          }
          id
        }
      }
    }
    favourites
  }
}
        '''
        variables = {
            'id': sQ
        }  

        url = 'https://graphql.anilist.co'

        response = requests.post(url, json={'query': query, 'variables': variables})
        self.raw = json.loads(response.text)
        self.media = self.raw["data"]["Character"]

    def _test(self):
        return self.media

    def reload(self):
      return self.__init__(self.sQ)
    def json(self):
      return self.raw

    def name(self, format):
        return self.media["name"][format]    
    def image(self, SIZE):
        return self.media["image"][SIZE]
    def description(self):
        return self.media["description"]
    def media(self):
        return self.media["media"]["edges"]["node"]
